Page MenuHomePhabricator

D17634.diff
No OneTemporary

D17634.diff

diff --git a/src/applications/differential/xaction/DifferentialRevisionReviewTransaction.php b/src/applications/differential/xaction/DifferentialRevisionReviewTransaction.php
--- a/src/applications/differential/xaction/DifferentialRevisionReviewTransaction.php
+++ b/src/applications/differential/xaction/DifferentialRevisionReviewTransaction.php
@@ -183,8 +183,19 @@
// In all cases, you affect yourself.
$map[$viewer->getPHID()] = $status;
- // If the user has submitted a specific list of reviewers to act as (by
- // unchecking some checkboxes under "Accept"), only affect those reviewers.
+ // If we're applying an "accept the defaults" transaction, and this
+ // transaction type uses checkboxes, replace the value with the list of
+ // defaults.
+ if (!is_array($value)) {
+ list($options, $default) = $this->getActionOptions($viewer, $revision);
+ if ($options) {
+ $value = $default;
+ }
+ }
+
+ // If we have a specific list of reviewers to act on, usually because the
+ // user has submitted a specific list of reviewers to act as by
+ // unchecking some checkboxes under "Accept", only affect those reviewers.
if (is_array($value)) {
$map = array_select_keys($map, $value);
}

File Metadata

Mime Type
text/plain
Expires
Fri, May 10, 11:28 PM (3 w, 6 d ago)
Storage Engine
blob
Storage Format
Encrypted (AES-256-CBC)
Storage Handle
6284327
Default Alt Text
D17634.diff (1 KB)

Event Timeline